Q4 = {}
Q5 = {}

Q3 = {
9:
"""
Дайте определение инвариантного линейного подпространства относительно линейного
оператора.
No9

Линейное подпространство U ⊂ V называется инвариантным относительно линейного
оператора φ : V → V , если φ(U) ⊂ U, т.е. U – инвариантно, если φ(x) ∈ U для ∀x ∈ U.

 Будут ли ядро и образ линейного оператора инвариантными подпространствами? Ответ
необходимо обосновать.

Пусть φ: V→V – линейный оператор в конечномерном пространстве V. Определим ядро и
образ линейного оператора как
Ker(φ) = {x ∈ V: φ(x) = 0};
Im(φ) = {y ∈ V: ∃x ∈ V такой, что φ(x) = y}.
Ker(φ) и Im(φ) – инвариантные подпространства.
Пусть y ∈ Im(φ) ⇒ ∃x ∈ V: φ(x) = y, так как φ: V→V, то (φ(x) = y) ∈ V и поэтому φ(φ(x)) = φ(y) ∈
Im(φ), т.е. подпространство Im(φ)является инвариантным.
Пусть x ∈ Ker(φ) ⇒ φ(x) = 0. Тогда φ(φ(x)) = φ(0) = 0, φ(x) ∈ Ker(φ), а значит
подпространство Ker(φ) инвариантно.
""",
15:
"""
Любая квадратная матрица является корнем своего характерического многочлена.
A = [[1,2],[3,4]], A - λ = [[1-λ,2],[3,4-λ]]
найдем charpoly(A) : (1-λ)*(4-λ)-6= λ**2-5*λ-2
подставим матрицу А в charpoly и убедимся, что после вычислений получим 0 : [[7,10],[15,22]] - [[5,10],[15,20]]-[[2,0],[0,2]] = [[0,0],[0,0]] ч.т.д
""",
14:
"""
Теорема. • Пусть λ1, λ2, . . ., λs собственные значения, которые попарно различны. Тогда соответствующие им собственные векторы Х1, Х2, ..., Xs, – линейно независимы; • Если характеристический многочлен f(x) имеет n попарно различных действительных корней (n = dim V), то существует базис е', в котором A (матрица оператора) имеет диагональный вид; • Пусть V — вещественное линейное пространство и φ : V → V – линейный оператор. Пусть λ = ⍺ + i*ß, ß≠0 — комплексный корень характеристического уравнения fø(λ)=0. Тогда существуют пара линейно независимых векторов a,b ∈ V такие, что =

1. ф(a) = ⍺a - ßb
2. ф(b) = ⍺b + ßa
""",
11:
"""
Определитель матрицы (A(q) - lambda*eye(n)) называется характеристическим многочленом линейного оператора q (A(q) - матрица характеристического многочлена q в заданном базисе, eye(n) - единичная матрица)

A(q)(e1) = C.inv() * A(q)(e) * C , где C - матрица перехода от базиса e к e1, A(q)(e) - матрица оператора в базисе e, A(q)(e1) - матрица оператора в базисе e1

det(A(q)(e1) - lambda * I) = det(C.inv()) * det(A(q)(e) - lambda * eye(n)) * det(C)

det(A(q)(e1) - lambda * I) = 1/det(C) * det(A(q)(e) - lambda * eye(n)) * det(C)

det(A(q)(e1) - lambda * I) = det(A(q)(e) - lambda * eye(n))

= > определитель матрицы (A(q)(e1) - lambda * eye(n)), то есть характеристический многочлен оператора, не зависит от выбора базиса
""",
13:
"""
Оператор называется диагонализируемым, если существует базис, в котором его матрица является диагональной, элементы на диагонали которой соответствуют собственным значениям этого оператора.

Оператор диагонализируем, если сумма размерностей его собственных пространств равна размерности V; если геометрическая кратность элементов его спектра совпадает с их алгебраической кратностью; если V = прямой сумме его собственных пространств
""",
10:
"""
Собственный вектор - это такой ненулевой вектор x, для которого выполняется равенство q(x) = lambda*x, a lambda - собственное значение, соответствующее этому собственному вектору x

Спектор линейного оператора Sp(q) = {lambda из поля K (R или C): det(A(q) - lambda * eye(n)) = 0, т.е. A(q) - lambda * eye(n) - необратима}; 

Резольвентой линейного оператора называется множество таких значений lambda, что матрица (A(q) - lambda*eye(n)) обратима, т.е. Re(q) = {l из K(R или C): det(A(q) - lambda*eye(n)) != 0, т.е. матрица A(q) - lambda*eye(n) обратима}
""",
6:
"""
Линейным пространством над полем К наз мн-во V, элементы которого называются векторами и в котором определены операция сложения и операция умножения на число, такие, что выполнены аксиомы линейного пространства
M = Matrix([[1, -1, 1, -1, -5, 0], [0, 1, -1, 2, 4, 1]])
M.nullspace()
""",
16:
"""
Определение. Нормализованный ( т.е. со старшим коэффициентом равным 1) многочлен минимальной степени, который аннулирует матрицу (т.е., f(4) = 0), называется минимальным многочленом линейного оператора
q:V - V.

Согласно теореме Гамильтона-Кэли характеристический многочлен f.(1) = det (A. - XE) является аннулирующим многочленом (т.е., fo(A») = 0, но, вообще говоря, не является минимальным.

from sympy import *
init_printing()
A=Matrix([ [3,-3,2],[-1,5,-2], [-1,3,0]])
1 = symbols ('lambda')
f = factor(A.charpoly() .as_expr))
A1 = A - 1*eye(3)
f1 = factor (A1. det ())
A2 = factor (A1. adjugate ())
list(A2)
d = gcd(list(A2))
h_min = (-1)**3*f1/d
""",
1:
"""
Линейное пространство - математическая структура, представляющая собой набор элементов, называемых  векторами, для которых определены операции сложения друг с другом и умножения на число - скаляр. Эти операции подчинены восьми аксиомам. Скаляры могут быть элементами любого поля чисел.
Аксиомы
1 x+y=y+x
2 x + (y+z) = (x+y) + z
3 x + 0 = x
4 -x + x = 0
5 a(bx) = (ab)x
6 1x=x
7(a+b)x = ax + bx
8 a(x+y) = ax + ay
""",
4:
"""
Определение. L≠Ø C V над полем Ҝ называется линейным подпространством, если • для любых a,b ∈ L → a + b ∈ L; • для любого α ∈ K u a ∈ L → α * a ∈ L. Другими словами, L – линейное подпространство, если L замкнуто относительно операции сложения и умножения. Пример. Определим линейную оболочку векторов е1, e2,..., ек как всевозможные линейные комбинации этих векторов, так что L =< е1,е2,..., ek > = span{e1, e2,..., ek} = {α1e1 + α2e2 +...+ αk*ek, α1, α2, ..., αk ∈ K}. Тогда L – линейное подпространство.
-
Примеры линейных подпространств:
Пространство решений однородной СЛАУ с n неизвестными в ℝ^n;
Линейная оболочка векторов;
Множество симметрических матриц в множестве квадратных матриц.
-
Вообще говоря, объединение двух линейных подпространств не является линейным подпространством. Достаточно контрпримера, к примеру, в пространстве ℝ2. Линейная оболочка вектора a, линейная оболочка вектора b, оба линейные подпространства, их объединением являются две прямые (продолжения векторов). Однако, сумма векторов a и b не входит в объединение их линейных оболочек => оно не является линейным подпространством.
"""
}

Q1 = {
2:
"""
Редуцированной ступенчатой формой наз-ся ступенчатая матрица, если подматрица, составленная из всех ее основных (ведущих) столбцов  явл-ся единичной. 
Теорема:
Любую СЛАУ или же любую матрицу можно привести к редуцированному ступенчатому виду. 
Неоднородная СЛАУ Ax=b будет совместной, если однородная СЛАУ является определенной или неопределенной при условии что в ступенчатой форме отсутствуют уравнения вида 0=b(i) при b(i) != 0. В первом случае мы получим в ступенчатой форме a(mn)x(n) = b(n) => x(n) = a(mn)/b(n). Подставляя в другие уравнения мы можем получить решение системы. Во втором случае если у нас в ступенчатой форме уравнения вида 0 = b(i) при b(i) != 0, то мы можем придать свободным переменным любые значения и выразить через них главные переменные
""",
5:
"""
Матрица - это объект, записываемый в виде прямоугольной таблице, который представляет собой совокупность строк и столбцов. Количество строк и столбцов задаёт размер матрицы. Матрица применяется для решения СЛАУ и СЛФР (систем линейных алгебраических и дифференциальных уравнений). Количество строк (m) определяет количество уравнений, а количество столбцов (n) - количество переменных. Для матриц определены операции: 
сложение (если размеры матриц совпадают)
умножение матриц подходящего размера (m*k) x (k*n) [если жирные значения равны, то получается матрица размером m * n - то есть, количество столбцов слева = количеству строк справа] 
умножение матрицы на вектор столбец или строку (частный случай умножения матриц)
умножение матрицы на число
Симметрическая матрица - это квадратная матрица, которая равна себе транспонированной. Кососимметрическая матрица - это квадратная матрица, которая равна минус себе транспонированной. 

Можно ли представить квадратную матрицу в виде суммы симметрической и кососимметрической? 
Да, во-первых матрица квадратная, как и любая (косо)симметрическая матрица. Значит при их сложении мы получим квадратную матрицу. 
 
Да, так как во первых слагаемые матрицы тоже будут квадратными, так как они 
(косо)симметрические, а так же потому, что чтобы получить эти матрицы в симметрической надо поставить на ij и ji элементы полусумму ij и ji элементов изначальной матрицы, а в кососимметричную на  ij и ji элементы полуразность ij и ji элементов изначальной матрицы с разными знаками
""",
4:
"""
ФСР однородной СЛАУ. 
Если ранг матрицы однородной СЛАУ равен r та такая система имеет n-r линейно независимых решений: фи(символ не вставляется)1, фи2,…,фиn-r. 
Любая совокупность n-r линейно независимых решений однородной СЛАУ называется фундаментальной системой решений данной СЛАУ. 
теорема об общем виде решения:
решением СЛАУ называют набор значений неизвестных переменных (x1=a1, x2=a2,…,Xn = an), обращающий все уравнения системы в тождество. 
Если решения фи1,фи2,…,фиn-r образуют ФСР, и X - матрица переменных данной СЛАУ, то общее решение СЛАУ можно представить в таком виде: X1 = C1* фи1+C2*фи2+…+Cn-r*фиn-r, где C1,C2,…,Cn-r - произвольные постоянные. Найдите ФСР 2*x1+3*X2-3*x3+4*x4-7*x5=0:
так как  неизвестных 5 ранг матрицы[2,3,-3,4,-7] = 1, то ФСР состоит из 5-1 векторов. 
x1+ 3/2*x2 - 3/2*x3 +4/2*x4 -7/2*x5=0 
выражаем x через оставшиеся 
x1 = -3/2*x2 +3/2 *x3 -2*x4 +7/2*x5 
фср: e1= [-3/2, 1 , 0 , 0, 0].T , e2 = [3/2,0,1,0,0].T, e3 = [-2,0,0,1,0].T, e4 = [7/2,0,0,0,1].T
""",
9:
"""
Понятие элементарной матрицы
Квадратичная матрица, получающаяся из единичной матрицы в результате одного элементарного преобразования называется
элементарной матрицей, соответствующей этому преобразованию.
p(ij)-1 == p(ij)
док-во:Умножение на элементарную матрицу P(ij) соответствует преобразованию "перестановка i-ой и j-ой строк (при умножении слева,
справа для перестановки столбцов)", т.е. матрица P(ij) получается из единичной матрицы в результате перестановки её i-ой и j-ой
строк. => при перестановке i-ой и j-ой строк в матрице P(ij), т.е. при умножении ее на матрицу P(ij), получается единичная матрица. =>
матрица P(ij) является обратной к матрице P(ij).
Mi(a)-1 == Mi(1/a)
док-во: Умножение на элементарную матрицу M(i)(α) соответствует преобразованию "умножение i-ой строки а α", т.е. матрица M(i)(α)
получается из единичной матрицы в результате умножения i-ой строки на α. => при умножении i-ой строки на (1/α) получается
единичная матрица => матрица M(i)(1/α) является обратной к матрице M(i)(α).
[Aji(a)]**-1 == Aji(-a)
док-во: 
Умножение на элементарную матрицу A(ji)(α) соответствует преобразованию "прибавление к j-ой строке i-ую строку, умноженную на
α (при умножении на матрицу слева)", т.е. матрица A(ji)(α) получается из единичной матрицы в результате прибавления к j-ой строке
i-ую строку, умноженную на α. => при прибавлении к j-ой строке i-ую строку, умноженную на (-α) получается единичная матрица =>
матрица A(ji)(-α) является обратной к матрице A(ji)(α).
примеры: 
I = eye(3)
P12 = Matrix([[0, 1, 0], [1, 0, 0], [0, 0, 1]]) # элементарная матрица "перестановка 1-ой и 2-ой строк"
P12, P12*P12
""",
    1: """СЛАУ - это система m уравнений n переменных, каждое уравнение в которой является линейным (то есть первой степени). СЛАУ является однородной, если все свободные члены = 0. Неоднородной в другом случае. (Определитель неоднородной системы = 0). СЛАУ называется определенной, если у неё есть только единственное решение, иначе она называется неопределенной. СЛАУ является линейно зависимой, если некоторую строку можно представить в виде комбинации других строк. Иначе, она является независимой. Если система является линейно независимой, то она не может быть неопределенной. Если система является линейно зависимой, то она может быть как определенной, так и неопределенной. """,
    3: """Рангом матрицы называют максимальное число линейно независимых строк (т.е тех, которых нельзя представить в виде других строк, они же - единичные строки). Система является совместной, если у неё есть хотя бы одно решение и несовместной, если решений нет. Теорема Кронекера-Капелли гласит, что СЛАУ является совместной ⇔ ранг основной матрицы равен рангу её расширенной матрицы. Расширенная матрица - это матрица, которой справа дописали ещё столбец свободных членов.

ЛНЗ матрицу можно привести к RREF, тогда она имеет строго одно решение, а значит совместна. Если матрица ЛЗ, то количество решений ≥ 1 а значит - совместна.""",
    6: """Произведение матриц - это матрица, получаемая в результате операции умножения. Умножить матрицу A на матрицу B можно только в случае, если они совместимы. То есть количество столбцов A = строк B.
Свойства произведения матриц: 
A * B * C = (A*B) * C = A * (B*C)
a * (A*B) = (a*A) * B = A * (a*B)
A*(B+C) = A*B + A*C
I * A = A, где I - единичная матрица
A * 0 = 0
Свойства произведения двух квадратных матриц:
A^2 = A*A
A*[A^(-1)] = I. То есть умножение матрицы на обратную себе

Если даны две квадратные матрицы A и B, то может произойти такое, что сумма всех элементов будет равна нулю. Так как мы складываем произведения строк и столбцов, мы можем подобрать такие значения.

Коммутирующие матрицы A и B называются такими, если A*B = B*A
Равенство (A*B)^T = A^T * B^T - верное""",
    7: """Произведение Кронекера A x B - это матрица, в которой каждый элемент из A умножается на полную матрицу B. Все вычисления записываются в одну матрицу.

Пусть даны квадратные матрицы А порядка m и матрица B порядка n. Прямой суммой матриц А и В называют квадратную блочную матрицу С = А ⊕ В порядка m + n.
След кронекерова произведения матриц A B равен произведению следов каждой матрицы по отдельности. По свойству.""",
    8: """Обратимая матрица - это матрица, у которой есть обратная матрица. Критерий обратимости: квадратная матрица и 
        sневырожденной (то есть det (A) != 0)
        Свойства обратных матриц:
        (A^-1)^-1 = A
        det (A^-1) = 1/det (A)
        (A*B)^-1 = B^-1 * A^-1
        (A^T)^-1 = (A^-1)^T
        (kA)^-1 = k^-1 * A^-1
        E^-1 = E""",
    10: """Для того, чтобы найти обратную матрицу методом Гаусса-Жордана, требуется:
        1. Записать матрицу A
        2. Записать расширенную матрицу A (приписать справа единичную матрицу такого же размера)
        3. С помощью элементарных преобразований, добиться того, чтобы левая часть расширенной матрицы приняла форму единичной матрицы
        4. Матрица справа, получившаяся в результате преобразований и есть обратная матрица""",
    11: """Любую невырожденную квадратную матрицу А порядка n можно представить в виде произведения элементарных матриц порядка n.
            А**- 1 = E_{k} * E_{k – 1} * … * E_{1} = E_{k} * E_{k – 1} * … * E_{1} * E
            Отсюда видно, что если мы к матрице E применим ту же самую цепочку элементарных преобразований строк, с помощью которой из 
            матрицы А**-1. Отметим, что эти преобразования можно выполнять одновременно, а для этого достаточно справа к матрице А приписать единичную матрицу того же порядка.""",
    12: """Найдём алгоритм K = LU
Приведём K к виду U (все элементы ниже главной диагонали = 0)
Умножаем K на U^-1 (обратную U), получаем L.
L * U = K""",
    14: """Минор матрицы A - это определитель матрицы меньшего порядка, чем порядок матрицы A.
Алгебраическое дополнение элемента a из матрицы A с координатами i, j - это минор элемента a умноженный на (-1)^(i+j)""",
    15: """A ** -1  = A.adj() / det(A)
A ** -1 * det(A) = A.adj()
A * A**-1 * det(A) = A.adj()
I * det(A) = A * A.adj()
""",
    16: """1.det(A).T = det(A)
2. Мы можем вынести общий множитель из строки/столбца за знак определителя
3. Перестановка двух строк/столбцов в матрице меняет знак определителя на противоположный
4. Если матрица содержит нулевую строку/столбец, то det = 0
5. Если две строки/столбца равны, то det = 0
6. Если две строки пропорциональны друг другу, то det = 0
7. Если матрица имеет треугольный вид, то определитель равен произведению элементов на главной диагонали
8. Мы можем разложить строку на сумму элементов. Тогда определитель общей матрицы будет равен сумме определителей разложенных матриц
9. Определитель не изменится, если к элементам любой его строки (или столбца) прибавить соответствующие элементы другой строки (или соответствующего столбца), умноженные на одно и тоже число:
10. Определитель произведения матриц равен произведению определителей матриц. det(AB) = det(A) * det(B)

Определитель кососимметрической матрицы нечетного порядка:
det(A) = det(-A.T) по свойству кососимметрической матрицы
вынесем из каждой строки/столбца коэф. -1.
Тогда по свойству:
det(A) = (-1)^n * det(A)
n – кол-во строк/столбцов матрицы.
т.к. n – нечётное:
det(A) = -det(A) => det(A) = 0.""",
    18: """Вопрос 18 минор — это определитель, который остается после вычеркивания определенной строки и определенного столбца. 
        Например, M 12 M 12 получается вычеркиванием 1-й строки и 2-го столбца, M 34 M 34 — вычеркиванием 3-й строки и 4-го столбцаСколько 
        различных миновало для матрицы Mmn? - сумма от к=1 по n (C из n по k * C из m по k)""",
    19: """Ранг матрицы равен максимальному порядку ненулевого минора. Базисный минор - это любой ненулевой минор максимального порядка. 

Теорема о базисном миноре: столбцы матрицы A, входящие в базисный минор, образуют линейно независимую систему.
1. Если в матрице есть ненулевой элемент, то ранг >= 1 и при этом не ранг <= N (кол-во строк/столбцов)
2. Дальше смотрим минор второго порядка. Если есть минор, определитель которого не равен 0 => ранг матрицы >= 2. Иначе ранг матрицы = 1.
 3. Дальше смотрим минор третьего порядка (если есть). Если есть минор, определитель которого не равен 0 => ранг матрицы >= 3. Иначе ранг матрицы = 2.
4. Перебор идёт дальше до тех пор, пока не встретится минор, равный 0
""",
    21: """Комбинаторно-аналитическим определением детерминанта называют выражение вида:
det A = sum (−1)^σ(π) a(i1)1*a(i2)2*...*a(in)n
A = Matrix([[2, 3], [9, 7]]) det(A) = ((-1)^(1+1))* 27 + ((-1)^(1+2)) 39 = 27 - 3*9 = 14 - 27 = -13

A = Matrix([[2, 3, 4], [9, 7, 3], [6, 9, 1]]) det(A)=((-1)(1+1))*2 * det(Matrix([[7, 3], [9, 1]])) + ((-1)(1+2))*3 * det(Matrix([[9, 3], [6, 1]])) + ((-1)**(1+3))*4*det(Matrix([[9, 7], [6, 9]]))

Или: определитель матрицы - это сумма всех перестановок элементов, где знак перед произведением определяется количеством инверсией в перестановке этих элементов.
"""}

Q2 = {8:
"""
Многочлен от n переменных - конечная сумма одночщенов от n переменных.
Р = сумма (с * х1^i1 * х2^i2 * … * хn^in)

Симметрический многочлен - многочлен от n переменных, не изменяющийся при любых перестановках переменных. 
Чаще всего записывается в виде многочлена от элементарных симметрических многочленов, представляющих собой суммы всевозможных мономов соответствующей системы: σк(х1,х2, …, хn) = сумма(хi1 * хi2 * … * хiк)

Пример:
σ1 = х1 + х2 + … + хn
σ2 = х1х2 + х1х3 + … + хn-1хn
.
σn = х1 * х2 * … * хn
""",
5:
"""
Алгебраической кратностью корня c называется такое k, что f | (x - c) ^ k, но не делится на f | (x - c) ^ k+1.
Алгебраическая кратность - наибольшая степень k, такая, что f | (x - c) ^ k.

Пример: f = (х - 4) ^ 2 * (х + 3). Здесь с = 4 - корень кратности 2, а с = -3 - простой корень. 

Корень с принадлежит К многочлена f принадлежит k[x] называется простым, если f не делится на (x - c) ^ 2, и кратным в противном случае. 

Основная теорема алгебры многочленов над полем комплексных чисел:

Пусть f принадлежит С[x] - произвольный отличный от константы многочлен степени n, deg(f) = n >= 1, т.е. f = сумма ak * z ^ k, начиная с k = 0 по n, аn не равно 0, а0, а1, …, аn принадлежит С. 
Тогда  f имеет ровно n комплексных корней с учетом их кратностей. Всякое уравнение an * z ^ n + an-1 * z ^ n-1 + … + a1 * z + а0 = 0, где an, an-1, …, а1, а0 принадлежит С, n >= 1, аn не равно 0, имеет по крайней мере один комплексный корень. 

Поле К называется алгебраически замкнутым, если каждый многочлен f принадлежит k[x] раскладывается на линейные множители. 
Или поле К алгебраически замкнуто, если любое множество  f deg(f) = n > 0 имеет в этом поле хотя бы один корень. 

Поле комплексных чисел алгебраически замкнуто. Док-во:
Пусть f - произвольное множество  deg(f) = n > 0 из F[x]. Если f(0) = 0, то 0 - корень множества  f. 
Допустим, что  f(0) != 0 и положим М = |f(0)|.
Пусть r > 0 такое, что любое z подмножество С: |z| <= r –> M <= |f(z)| (1)
Пусть K = {z подмножество С: |z| <= r}. Функция |f(z)| достигает наименьшего значения на множестве К, т.е. существует а, принадлежащее К, что |f(а)| <=  |f(z)|, для любого z, принадлежащего К (2)
|z| <= r, |f(а)| <=  |f(0)| = М (3)
Из (1) и (3) получаем: (4) любое z подмножество С: |z| <= r –> |f(а)| <=  |f(z)| 
Из (2) и (4) =>  любое z подмножество С:  |f(а)| <=  |f(z)| 
Если f(а) != 0, то существует с, принадлежащее С, |f(с)| <=  |f(z)|, что противоречит (3) => случай, когда  f(а) != 0 невозможен => f(а) = 0, т.е а - корень множества f.
""",
4:
"""
Неприводимый многочлен - это многочлен, который нельзя представить в виде произведения нескольких многочленов. 

x^4+4 = (x^2-2x+2)(x^2+2x+2) - приводим над R (и, получается, над C)
""",
3:
"""
НОД многочленов называется такой многочлен наибольшей степени, на который делится каждый из многочленов без остатка. НОД определяется с точностью до числового множителя. 

d(x) - НОД, если делится на любой другой их общий делитель (х):
d(x) mod (х) = 0, d(x) = D(f1(x), f2(x), …, fn(x))

НОК многочленов называется такой многочлен наименьшей степени, который делится на каждый из многочленов без остатка; определяется с точностью до числового множителя.

По алгоритму Евклида:
d = r1 - q3 * r2
r2 = g - q2 * r1
r1 = f - g * q1

d =  r1 - q3 * ( g - q2 * r1) = r1 + q3 * q2 * r1 - q3 * g = r1 * (1 + q3 * q2) - q3 * g = (f - q1 * g) * (1 + q3 * q2) + (-q3) * g = f * (1 + q3 * q2) + g * (-q1 - q1 * q2 * q3) + g * (-q3) = f * (1 + q3 * q2) + g (-q1 - q3 - q1 * q2 * q3)

Код:
x = Symbol(“x")
f = 2*x**3 - 7*x**2 - 9*x + 63
g = x**3 + x**2 - 19*x - 9
q1, r1 = div(f, g)
q2, r2 = div(g, r1)
q3, d = div(r1, r2)
#r1 = q3*r2 + d
#g = q2*r1 + r2
#f = q1*g + r1

#d= r1 - q3*r2
#r2 = g - q2*r1
#r1 = f - q1*g
a, b, *trash = gcdex(f, g)
simplify(f*a+g*b)

u = simplify(1+q3*q2)/d
simplify(u)
v = simplify((-q1 - q1*q3*q2 - q3)/ d)
simplify(f*u + g*v), u, v
""",
2:
"""
Корнем n-ой степени из комплексного числа z называется такое комплексное число w, n-я степень которого равна w^n = z.
Выведем формулу для извлечения корня n-ой степени из комплексного числа, пользуясь определением. Пусть z = r * (cosφ + i * sinφ) = p \ро\ *(cosα + i * sinα) = 3√z. Имеем по определению ((cosα + i * sinα)) ^ n = z, откуда по формуле Муавра получим ( р ^ n) * (cos(nα) + i * sin(nα)) = r * (cosφ + i * sinφ) =>  р ^ n = r, nα = φ + 2пk, k принадлежит Z =>  р =  n√r, α = (φ + 2пk) / n => n√z = n√r * (cos((φ + 2пk) / n) + i * sin((φ + 2пk) / n)),  k принадлежит Z.

Геометрическая интерпретация
Извлечения корня n-ой степени из z не равно 0 всегда возможно и все n значений w0, w1, …, wn-1 расположены в вершинах правильного n угольника с центром в (0) и R = n√|z|
n√|z| = {w0, w1, …, wn-1}
""",
9:
"""
Sk(x1..xn)=sum xi1*xi2*..*xik k=1,2,n
s1 = x1+x2+x3+x4
𝑠2= 𝑥1𝑥2+𝑥1𝑥3+𝑥1𝑥4+𝑥2𝑥3+𝑥2𝑥4+𝑥3𝑥4
𝑠3 =𝑥1𝑥2𝑥3+𝑥1𝑥2𝑥4+𝑥1𝑥3𝑥4+𝑥2𝑥3𝑥4
𝑠4= 𝑥1𝑥2𝑥3𝑥4
""",
7:
"""
Пусть f ∈ R[z], deg(f) 0, a0, a1, a2, ..., an ∈ R. = n, т.е. f(z) = a0 + a1*z + a2*z^2 + ... + an*z^n, an ≠ 0
Теорема. Если комплексное число w0 Є С является корнем многочлена f (т.е. f(w0) = 0), mo сопряженное к w0 также является корнем того же много- члена, причем той же кратности, что и w0.
Следствие. Если w0 = a+bi, (b ≠ 0) является корнем многочлена f(z) с действи- тельными коэффициентами, то f(z) делится (без остатка) на квадратный трехчлен (z - w0)(z - w0) = z^2 + 2az + a² + b^2. 
Теорема (каноническое разложение многочлена с действительными коэффициентами). Любой ненулевой многочлен f ∈ R[x], deg(f) = n с действительными коэффициентами раскладывается в произведение линейных множителей вида х — ci, отвечающим действительным корням с ∈ R, и произведение квадратных трехчленов, неприводимых над R (т.е. у которых дискриминант отрицателен), соответствующим парам комплексно сопряженным корням wk = ak + bk*i, bk ≠ 0.

Доказательство. Поскольку с корень многочлена f (x) = a0*x^n + а1*x^(n-1) + ... + a(n-1)*х + an, имеем
а0*c^n + a1*c^(n-1) + ... + a(n-1)*c + an = 0.
Из свойств операции сопряжения вытекает, что равенство не изменится при замене всех чисел на сопряженные к ним. Так как применение опе- рации сопряжения к действительным числам а0, а1, an-1, an и 0 не изменяет эти числа, получаем
а0*č^n + a1*č^(n-1) + ... + a(n-1)*č + an = 0, т. е. f(č) = 0.

Разложите многочлен f = x^5-1 над ℝ
""",

1:
"""
Комплексное число - это число вида a + bi, где a, b - действительные числа, а i - так называемая мнимая единица. Такая, что i^2 = -1. Число a называется реальной (действительной) частью, а bi - мнимой частью. Таким образом, мы всегда можем представить любое действительное число через комплексные (при b = 0). Значит - действительные числа - это частный случай комплексного числа. 

Тригонометрическая форма записи комплексного числа: z = r(cos(fi)+isin(fi)).
Показательная форма комплексного числа: z = re^(i * (fi))
""",

13:
"""
Результант многочленов:
f(x) = a0x^n + a1x^n-1 + … + an, a0 != 0
g(x) = b0x^m + b1x^m-1 + … + am
называется определитель матрицы порядка (n + m)

Res(f(x); g(x)): |a0 a1  a2 … an 0 … 0|
                        |0   a0  a1 … an 0 … 0|
                             …
                         |0 … 0  a0 a1 a2 … an|
                         |b0 b1  b2 … bm 0 … 0|
                        |0   b0  b1 … bm 0 … 0|
                            …
                        |0 … 0  b0 b1 b2 … bm|


f = x **4 - 10*x**2 + 1
g = x 4 - 4 * sqrt(2) * x  3 + 6 * x  2 + 4 * sqrt(2) * x + 1
for root in solve(f):
  for o_root in solve(g):
    if float(root) == float(o_root):
      display(‘Некоторые корни совпадают’, root, o_root)
# => по свойству результанта он равен нулю
# => или просто по функции
res = resultant(f, g)
res

f = x 4 - 10*x**2 + 1
g = x **4 - 4 * sqrt(2) * x  ** 3 + 6 * x ** 2 + 4 * sqrt(2) * x + 1
res = resultant(f, g)
res
u = g
v = -f
simplify(f*u + g*v) == res
""",
12:
"""
Пусть f(z) = a0z^n+a1z^n−1+a2z^n−2+. . .+an−1z+an принадлежит C[z], a0 != 0 – произвольный многочлен с комплексными коэффициентами, и пусть c1, c2, . . . , cn – его корни (вещественные или комплексные, возможно кратные (не важно)). По формулам Виета мы знаем, что sk(c1, c2, . . . , cn) = (−1)^k * (ak/a0), k = 1, 2, . . . , n;

Здесь sk(c1, c2, . . . , cn) = cумма 1<= i1<i2<···<ik<=n (xi1, xi2, …, xik), k = 1, 2, . . . , n – элементарные симметрические многочлены, вычисленные на корнях c1, c2, . . . , cn многочлена f(z).

Дискриминантом семейства корней c1, c2, . . . , cn или дискриминантом многочлена f(z) называется выражение Dis(f) = a0 ^ 2n−2 * П 1<= i< j <=n (ci − cj )^2

Заметим, что дискриминант является симметрическим многочленом и как
любой симметрический многочлен можно выразить однозначно через элементарные симметрические многочлены, и учитывая формулы Виета, мы получаем зависимость дискриминанта многочлена от его коэффициентов: 
Dis(f) = Dis(s1, s2, . . . , sn) |sk=(−1)^k * (ak/a0) = F(a0, a1, . . . , an).

Свойства дискриминанта: 
1) Dis=0, когда многочлен имеет кратные корни 
2) Dis является симметрическим многочленом относительно корней многочлена и является многочленом от его коэффициентов

Возьмем многочлен f(z)=az³ + bz² + cz + d 
Его дискриминант будет равен: Dis = b²c² - 4ac³ - 4b³d - 27a²d² + 18abcd 
Теперь рассмотрим другой многочлен f(z)=z³+az+b 
Сравнив эти многочлены, заметим, что a=1, b=0, c=a,d=b 
Тогда Dis = -4a³ - 27b²
""",
11:
"""
Любой симметрический многочлен f(x1, …, xn) можно выразить через элементарные симметрические многочлены, причем единственным образом, т.е. существует единственное F(y1, …, yn): f(x1, …, xn) = F(σ1, …, σn)

f(x1, x2, x3) = x1^3x2 + x2^3x1 + x3^3x1 + x2^3x1 + x3^3x2 + x1^3x3

Слагаемые имеют вид: x1^3x2, значит старшая степень при 1 перестановке 3, а сумма степеней равна 4. 

Запишем неубывающие последовательности цифр по условию:
3 1 0: σ1^3-1σ2^1 = σ1^2σ2
2 1 1: σ1^2-1σ2^1-1σ3^1= σ1σ3
2 2 0: σ1^2-2σ2^2 = σ2^2

Количество чисел в последовательности равно числу переменных.

(1) σ1 = х1 + х2 + х3; σ2 = х1х2 + х1х3 + х2х3; σ3 = х1х2х3

Тогда наш многочлен запишем через перестановки. Коэффициент перед старшей степенью равен 1. 

F = σ1^2σ2 + B * σ2^2 + C * σ1σ3

Найдем В и С методом неопределенных коэффициентов. 

1) Пусть х1 = х3 = 1, х2 = 0
F(1, 0, 1) = (1 + 0 + 1)(0 + 1 + 1) + В * 1 + С * 1 * 0 = 4 + В
f(1, 0, 1) = 0 + 0 + 1 + 0 + 0 + 1 = 2
по теореме F(1, 0, 1) = f(1, 0, 1), тогда 4 + В = 2; В = -2

Тогда F = σ1^2σ2 - 2 * σ2^2 + C * σ1σ3

2) Пусть х1 = х2 = 1, х3 = -1
F(1, 1, -1) = (-1 + 1 + 1) ^ 2 (1 - 1 - 1) - 2 * (1 - 1 - 1)  ^ 2 + С * 1 * (-1) = 1 * (-1) - 2 * 1 - С = -3 - С
f(1, 1, -1) = 1 + 1 + (-1) + 1 - 1 - 1 = -2
 F(1, 1, -1) = f(1, 1, -1) => -3 - С = -2; -3 + 2 = С, т.е. С = -1

Получим F = σ1^2σ2 - 2 * σ2^2 - σ1σ3, где (1)
""",
6:
"""
Q2 6

Пусть f(z) = a0z^n + a1z^n-1 + … + an-1z + an принадлежит С[z], где deg(f) = n, a0 != 0, имеет n корней с1 … сn, среди которых, возможно, есть и одинаковые. Тогда справедливо разложение f(z) = а0(z - с1)(z - с2)...(z - сn)

Приравнивая коэффициенты при одинаковых степенях =>
с1 + с2 + с3 + … + сn = -а1/а0
с1с2 + с1с3 + … + с1сn + с2с3 + … + сn-1сn = а2/а0
…
cумма 1<= i1<i2<···<ik<=n (сi1, сi2, …,сik) = (−1)^k * (ak/a0)
с1с2 + с1с3 + … + с1сn + с2с3 + … + сn-1сn = (−1)^k * (an-1/a0)
с1с2…сn = (−1)^т * (an/a0)

Элементарные симметрические многочлены:
sk(c1, c2, . . . , cn) = cумма 1<= i1<i2<···<ik<=n (хi1, хi2, …,хik), k = 1, 2, . . . , n;

Тогда формула Виета:
sk(c1, c2, . . . , cn) =  (−1)^k * (ak/a0), k = 1, 2, . . . , n;
или
ak/a0 = (−1)^k * sk(c1, c2, . . . , cn), k = 1, 2, . . . , n.
"""
}

def find(words):
    for i in set(Q1.values()) | set(Q2.values()) | set(Q3.values()):
        for f in words.split():
            if f.lower() not in i.lower():
                break
        else:
            print(i)
            print('\n'+'-'*30)






